@@ -1,4 +1,5 @@
 import sensenet.importers
+
 tf = sensenet.importers.import_tensorflow()
 kl = sensenet.importers.import_keras_layers()
 
@@ -11,8 +12,9 @@ from sensenet.load import load_points, count_types
 from sensenet.models.settings import ensure_settings
 from sensenet.preprocess.preprocessor import Preprocessor
 
+
 def instantiate_inputs(model, settings):
-    ncols, nimages = count_types(model['preprocess'])
+    ncols, nimages = count_types(model["preprocess"])
 
     if nimages > 0:
         if nimages > 1:
@@ -25,17 +27,20 @@ def instantiate_inputs(model, settings):
         if nimages == ncols:
             return im_input
         else:
-            num_input = kl.Input((ncols,), dtype=tf.float32, name=NUMERIC_INPUTS)
+            num_input = kl.Input(
+                (ncols,), dtype=tf.float32, name=NUMERIC_INPUTS
+            )
             return {NUMERIC_INPUTS: num_input, PIXEL_INPUTS: im_input}
     else:
         return kl.Input((ncols,), dtype=tf.float32, name=NUMERIC_INPUTS)
 
+
 def apply_layers(model, settings, inputs, treeed_inputs):
-    if 'networks' in model:
-        all_layer_sequences = [net['layers'] for net in model['networks']]
-        use_trees = [net.get('trees', False) for net in model['networks']]
-    elif model['layers']:
-        all_layer_sequences = [model['layers']]
+    if "networks" in model:
+        all_layer_sequences = [net["layers"] for net in model["networks"]]
+        use_trees = [net.get("trees", False) for net in model["networks"]]
+    elif model["layers"]:
+        all_layer_sequences = [model["layers"]]
         use_trees = [treeed_inputs is not None]
     else:
         all_layer_sequences = [[]]
@@ -50,8 +55,8 @@ def apply_layers(model, settings, inputs, treeed_inputs):
         else:
             preds = feed_through(lseq, inputs)
 
-        if outex['type'] == NUMERIC and not settings.regression_normalize:
-            preds = preds * outex['stdev'] + outex['mean']
+        if outex["type"] == NUMERIC and not settings.regression_normalize:
+            preds = preds * outex["stdev"] + outex["mean"]
 
         all_predictions.append(preds)
 
@@ -63,6 +68,7 @@ def apply_layers(model, settings, inputs, treeed_inputs):
 
     return predictions
 
+
 def deepnet_model(model, input_settings):
     settings = ensure_settings(input_settings)
 
